@@ -4,7 +4,7 @@
 # This file is subject to the MIT License (see the LICENSE file).
 
 __copyright__ = '2010-2012, Silas Sewell'
-__version__ = '0.4.3'
+__version__ = '0.4.4'
 
 import collections
 import datetime
@@ -863,8 +863,7 @@ def run(command, **kwargs):
                     stderr_result += line
             else:
                 fds.remove(fd)
-        if ref.poll():
-            break
+    ref.wait()
     return obj({
         'code': ref.returncode,
         'command': command,
